==> fet-5.14.2.tar.bz2: fet-5.14.2/src/interface/constraintstudentssetmaxbuildingchangesperweekform.h <==
/***************************************************************************
                          constraintstudentssetmaxbuildingchangesperweekform.h  -  description
                             -------------------
    begin                : Feb 10, 2005
    copyright            : (C) 2005 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CONSTRAINTSTUDENTSSETMAXBUILDINGCHANGESPERWEEKFORM_H
#define CONSTRAINTSTUDENTSSETMAXBUILDINGCHANGESPERWEEKFORM_H

#include "ui_constraintstudentssetmaxbuildingchangesperweekform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

class ConstraintStudentsSetMaxBuildingChangesPerWeekForm : public QDialog, Ui::ConstraintStudentsSetMaxBuildingChangesPerWeekForm_template  {
	Q_OBJECT
public:
	SpaceConstraintsList visibleConstraintsList;

	ConstraintStudentsSetMaxBuildingChangesPerWeekForm();
	~ConstraintStudentsSetMaxBuildingChangesPerWeekForm();

	bool filterOk(SpaceConstraint* ctr);

public slots:
	void constraintChanged(int index);
	void addConstraint();
	void modifyConstraint();
	void removeConstraint();

	void filterChanged();
};

#endif

==> fet_5.28.1.orig.tar.bz2: fet-5.28.1/src/interface/constraintstudentssetmaxbuildingchangesperweekform.h <==
/***************************************************************************
                          constraintstudentssetmaxbuildingchangesperweekform.h  -  description
                             -------------------
    begin                : Feb 10, 2005
    copyright            : (C) 2005 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software: you can redistribute it and/or modify  *
 *   it under the terms of the GNU Affero General Public License as        *
 *   published by the Free Software Foundation, either version 3 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 ***************************************************************************/

#ifndef CONSTRAINTSTUDENTSSETMAXBUILDINGCHANGESPERWEEKFORM_H
#define CONSTRAINTSTUDENTSSETMAXBUILDINGCHANGESPERWEEKFORM_H

#include "ui_constraintstudentssetmaxbuildingchangesperweekform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

class ConstraintStudentsSetMaxBuildingChangesPerWeekForm : public QDialog, Ui::ConstraintStudentsSetMaxBuildingChangesPerWeekForm_template  {
	Q_OBJECT
public:
	SpaceConstraintsList visibleConstraintsList;

	ConstraintStudentsSetMaxBuildingChangesPerWeekForm(QWidget* parent);
	~ConstraintStudentsSetMaxBuildingChangesPerWeekForm();

	bool filterOk(SpaceConstraint* ctr);

public slots:
	void constraintChanged(int index);
	void addConstraint();
	void modifyConstraint();
	void removeConstraint();

	void filterChanged();
};

#endif
